# Generated by Django 4.1.2 on 2022-10-31 13:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcaps', '0002_pcap_rule_to_validate'),
        ('snort', '0002_alter_snortrule_options_alter_snortrule_extra_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='snortrule',
            name='pcap_validation',
            field=models.ManyToManyField(blank=True, null=True, related_name='validation_pcap', to='pcaps.pcap'),
        ),
    ]
