# Generated by Django 4.1.2 on 2022-10-31 13:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcaps', '0002_pcap_rule_to_validate'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pcap',
            name='extra',
            field=models.TextField(blank=True, max_length=256),
        ),
    ]
