# Generated by Django 4.1.2 on 2022-10-31 09:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('snort', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='snortrule',
            options={'ordering': ('name', 'type', 'date')},
        ),
        migrations.AlterField(
            model_name='snortrule',
            name='extra',
            field=models.TextField(blank=True, max_length=256),
        ),
        migrations.AlterField(
            model_name='snortrule',
            name='group',
            field=models.TextField(blank=True, max_length=100),
        ),
        migrations.AlterField(
            model_name='snortrule',
            name='main_ref',
            field=models.TextField(blank=True, max_length=12),
        ),
        migrations.AlterField(
            model_name='snortrule',
            name='request_ref',
            field=models.TextField(blank=True, max_length=12),
        ),
    ]
