# Generated by Django 4.1.2 on 2022-11-07 11:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('snort', '0008_alter_snortrule_group_alter_snortrule_location_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='snortrule',
            name='user',
            field=models.CharField(blank=True, default=0, max_length=100),
        ),
    ]
