# Generated by Django 4.1.2 on 2022-10-31 13:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcaps', '0003_alter_pcap_extra'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pcap',
            name='location',
        ),
        migrations.AddField(
            model_name='pcap',
            name='pcap_file',
            field=models.FileField(null=True, upload_to='pacp_repo/'),
        ),
    ]
