# Generated by Django 4.1.2 on 2022-11-07 06:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('snort', '0006_alter_snortrule_template_alter_snortrule_type'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='snortrule',
            name='template',
        ),
    ]
